@@ -111,7 +111,7 @@ typedef enum
 {
   CHATTY_STATUS_UNKNOWN,
   CHATTY_STATUS_DRAFT,
-  CHATTY_STATUS_RECIEVED,
+  CHATTY_STATUS_RECEIVED,
   CHATTY_STATUS_SENDING,
   CHATTY_STATUS_SENT,
   CHATTY_STATUS_DELIVERED,
